aboutsummaryrefslogtreecommitdiffstats
path: root/src/declarative/qml/qdeclarativecustomparser_p.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/declarative/qml/qdeclarativecustomparser_p.h')
-rw-r--r--src/declarative/qml/qdeclarativecustomparser_p.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/declarative/qml/qdeclarativecustomparser_p.h b/src/declarative/qml/qdeclarativecustomparser_p.h
index 31452836bd..47b3ee8f8e 100644
--- a/src/declarative/qml/qdeclarativecustomparser_p.h
+++ b/src/declarative/qml/qdeclarativecustomparser_p.h
@@ -55,7 +55,7 @@
#include "private/qdeclarativemetatype_p.h"
#include "qdeclarativeerror.h"
-#include "private/qdeclarativeparser_p.h"
+#include "private/qdeclarativescript_p.h"
#include "private/qdeclarativebinding_p.h"
#include <QtCore/qbytearray.h>
@@ -79,10 +79,10 @@ public:
~QDeclarativeCustomParserProperty();
QByteArray name() const;
- QDeclarativeParser::Location location() const;
+ QDeclarativeScript::Location location() const;
bool isList() const;
// Will be one of QDeclarativeParser::Variant, QDeclarativeCustomParserProperty or
// QDeclarativeCustomParserNode
QList<QVariant> assignedValues() const;
@@ -102,7 +102,7 @@ public:
~QDeclarativeCustomParserNode();
QByteArray name() const;
- QDeclarativeParser::Location location() const;
+ QDeclarativeScript::Location location() const;
QList<QDeclarativeCustomParserProperty> properties() const;
@@ -147,7 +147,7 @@ protected:
private:
QList<QDeclarativeError> exceptions;
QDeclarativeCompiler *compiler;
- QDeclarativeParser::Object *object;
+ QDeclarativeScript::Object *object;
Flags m_flags;
friend class QDeclarativeCompiler;
};
@@ -79,10 +79,10 @@ public:
bool isList() const;
- // Will be one of QDeclarativeParser::Variant, QDeclarativeCustomParserProperty or
+ // Will be one of QDeclarativeScript::Variant, QDeclarativeCustomParserProperty or
// QDeclarativeCustomParserNode
QList<QVariant> assignedValues() const;